# arpq
Asynchronous python library impementing priority queue based on Redis sorted sets. 

# Features
- support for many producers/consumers
- support for different encoders (json, msgpack, pickle, ...)

# Panned features
- support for different async redis libraries (aioredis, aredis, ...)
- batch task processing
- better control over encoders (passing different arguments for encode/decode)

# Examples
TODO
